import Vue from "vue";

/**
 * @author 张金龙
 * @information 防止抖动类
 * @date 2018-11-19 17:45
 */
export class PreventJitter {
    constructor(){
        this.timer = null;
    }

    start(dom,binding){
        let $this = this;
        dom.addEventListener("input",function(e){
            let {timer} = $this;
            clearTimeout(timer);
            $this.timer = setTimeout(() => {
                let {value} = this;
                binding.value({value});
            },500);
        });
    }

    static singleton(){
        let singleton = null;
        if(!singleton){
            singleton = new PreventJitter();
        }
        return singleton;
    }
}

Vue.directive('jitter-change', {
    inserted(el,binding) {
        let dom = el.getElementsByTagName("input")[0] || el;
        if(dom.nodeName !== "INPUT"){
            throw new Error("The 'input' tag was not found");
        }
        let preventJitter = PreventJitter.singleton();
        preventJitter.start(dom,binding);
    }
})